@@ -69,10 +69,10 @@ my_print_image_from_disk (GnomePrintContext *gpc)
 	/* Save the graphic context, scale, print the image and restore */
 	gnome_print_gsave (gpc);
 	gnome_print_scale (gpc, 144, 144);
-	
 	my_print_image_from_pixbuf (gpc, pixbuf);
-	
 	gnome_print_grestore (gpc);
+
+	g_object_unref (G_OBJECT (pixbuf));
 }
 
 static void
@@ -120,16 +120,19 @@ my_draw (GnomePrintContext *gpc)
 static void
 my_print (void)
 {
-	GnomePrintJob *gpm;
+	GnomePrintJob *job;
 	GnomePrintContext *gpc;
 
-	gpm = gnome_print_job_new (NULL);
-	gpc = gnome_print_job_get_context (gpm);
+	job = gnome_print_job_new (NULL);
+	gpc = gnome_print_job_get_context (job);
 
 	my_draw (gpc);
 
-	gnome_print_job_close (gpm);
-	gnome_print_job_print (gpm);
+	gnome_print_job_close (job);
+	gnome_print_job_print (job);
+
+	g_object_unref (gpc);
+	g_object_unref (job);
 }
 
 int
