@@ -224,6 +224,7 @@ preview_canvas_button_press (GtkWidget *widget, GdkEventButton *event, GnomePrin
 
 	if (event->button == 1) {
 		GdkCursor *cursor;
+		GdkDisplay *display = gtk_widget_get_display (widget);
 
 		mp->dragging = TRUE;
 
@@ -232,9 +233,11 @@ preview_canvas_button_press (GtkWidget *widget, GdkEventButton *event, GnomePrin
 		mp->anchorx = event->x - mp->offsetx;
 		mp->anchory = event->y - mp->offsety;
 
-		cursor = gdk_cursor_new (GDK_FLEUR);
+		cursor = gdk_cursor_new_for_display (display, GDK_FLEUR);
 		gdk_pointer_grab (widget->window, FALSE,
-				  (GDK_POINTER_MOTION_MASK | GDK_POINTER_MOTION_HINT_MASK | GDK_BUTTON_RELEASE_MASK),
+				  (GDK_POINTER_MOTION_MASK | 
+				   GDK_POINTER_MOTION_HINT_MASK | 
+				   GDK_BUTTON_RELEASE_MASK),
 				  NULL, cursor, event->time);
 		gdk_cursor_unref (cursor);
 
@@ -291,7 +294,8 @@ preview_canvas_button_release (GtkWidget *widget, GdkEventButton *event, GnomePr
 
 	if (event->button == 1) {
 		mp->dragging = FALSE;
-		gdk_pointer_ungrab (event->time);
+		gdk_display_pointer_ungrab (gtk_widget_get_display (widget),
+					    event->time);
 		retval = TRUE;
 	}
 
@@ -538,7 +542,56 @@ canvas_style_changed_cb (GtkWidget *canvas, GtkStyle *ps, GnomePrintJobPreview *
 			       "outline_color_rgba", border_color,
 			       NULL);
 }
+
+static void
+entry_insert_text_cb (GtkEditable *editable, const gchar *text, gint length, gint *position)
+{
+	gunichar c;
+	const gchar *p;
+ 	const gchar *end;
+
+	p = text;
+	end = text + length;
+
+	while (p != end) {
+		const gchar *next;
+		next = g_utf8_next_char (p);
+
+		c = g_utf8_get_char (p);
+
+		if (!g_unichar_isdigit (c)) {
+			g_signal_stop_emission_by_name (editable, "insert_text");
+			break;
+		}
+
+		p = next;
+	}
+}
+
+static gboolean 
+entry_focus_out_event_cb (GtkWidget *widget, GdkEventFocus *event, GnomePrintJobPreview *pjp)
+{
+	GPMPPrivate *priv;
+	const gchar *text;
+	gint page;
+
+	priv = (GPMPPrivate *) pjp->priv;
+
+	text = gtk_entry_get_text (GTK_ENTRY(widget));
+	page = atoi (text) - 1;
 	
+	/* Reset the page number only if really needed */
+	if (page != priv->current_page) {
+		gchar *str;
+
+		str = g_strdup_printf ("%d", priv->current_page + 1);
+		gtk_entry_set_text (GTK_ENTRY (widget), str);
+		g_free (str);
+	}
+
+	return FALSE;
+}
+
 static void
 create_preview_canvas (GnomePrintJobPreview *mp)
 {
@@ -608,14 +661,22 @@ create_preview_canvas (GnomePrintJobPreview *mp)
 				      "fill_color", "black",
 				      NULL);
 	gnome_canvas_item_lower_to_bottom (item);
-	gnome_canvas_set_scroll_region (priv->canvas, 0 - PAGE_PAD, 0 - PAGE_PAD, mp->paw + PAGE_PAD, mp->pah + PAGE_PAD);
+	gnome_canvas_set_scroll_region (priv->canvas, 0 - PAGE_PAD, 0 - PAGE_PAD, 
+					mp->paw + PAGE_PAD, mp->pah + PAGE_PAD);
 
 	status = gtk_hbox_new (FALSE, 0);
 	l = gtk_label_new_with_mnemonic (_("P_age: "));
 	gtk_box_pack_start (GTK_BOX (status), l, FALSE, FALSE, 4);
 	priv->page_entry = gtk_entry_new ();
-	gtk_widget_set_size_request (priv->page_entry, 40, 0);
-	g_signal_connect (G_OBJECT (priv->page_entry), "activate", (GCallback) change_page_cmd, mp);
+	gtk_widget_set_size_request (priv->page_entry, 40, -1);
+
+	g_signal_connect (G_OBJECT (priv->page_entry), "activate", 
+			  G_CALLBACK (change_page_cmd), mp);
+	g_signal_connect (G_OBJECT (priv->page_entry), "insert_text",
+			  G_CALLBACK (entry_insert_text_cb), NULL);
+	g_signal_connect (G_OBJECT (priv->page_entry), "focus_out_event",
+			  G_CALLBACK (entry_focus_out_event_cb), mp);
+
 	gtk_box_pack_start (GTK_BOX (status), priv->page_entry, FALSE, FALSE, 0);
 	gtk_label_set_mnemonic_widget ((GtkLabel *) l, priv->page_entry);
 
@@ -669,10 +730,6 @@ create_toplevel (GnomePrintJobPreview *mp)
 	width  = MIN (mp->paw + PAGE_PAD * 3, gdk_screen_width () - 40);
 	height = MIN (mp->pah + PAGE_PAD * 3, gdk_screen_height () - 40);
 
-	/* FIXME: This call is depreacated, left over from port to 2.0 (Chema)  */
-#if 0	
-	gtk_window_set_policy (GTK_WINDOW (mp), TRUE, TRUE, FALSE);
-#endif	
 	gtk_widget_set_size_request (GTK_WIDGET (mp), width, height);
 
 	/* This is not very beautiful, but works for now */
