@@ -29,6 +29,7 @@
 #include <math.h>
 #include <gtk/gtk.h>
 
+#define GNOME_PRINT_UNSTABLE_API
 #include "gnome-print-unit-selector.h"
 
 #define noGPP_VERBOSE
@@ -240,8 +241,14 @@ gpus_rebuild_menu (GnomePrintUnitSelector *us)
 	pos = p = 0;
 	for (l = us->units; l != NULL; l = l->next) {
 		const GnomePrintUnit *u;
+		gchar *name;
+		
 		u = l->data;
-		i = gtk_menu_item_new_with_label ((us->abbr) ? (us->plural) ? u->abbr_plural : u->abbr : (us->plural) ? u->plural : u->name);
+
+		name = gnome_print_unit_get_name (u, us->plural, us->abbr, 0);
+		i = gtk_menu_item_new_with_label (name);
+		g_free (name);
+
 		g_object_set_data (G_OBJECT (i), "unit", (gpointer) u);
 		g_signal_connect (G_OBJECT (i), "activate", (GCallback) gpus_unit_activate, us);
 		gtk_widget_show (i);
